=== modified file 'NEWS'
--- NEWS	2010-06-28 03:23:26 +0000
+++ NEWS	2010-06-28 21:45:10 +0000
@@ -54,6 +54,10 @@
 * ``bzr log --exclude-common-ancestry`` is now taken into account for
   linear ancetries. (Vincent Ladeuil, #575631)
 
+* ``bzr log -r branch:REMOTE`` can now properly log the remote branch,
+  rather than trying to fetch the data locally and failing because of a
+  readonly error. (Martin von Gagern, #149270)
+
 * ``bzr pull`` now works when a lp: URL is explicitly defined as the parent
   or pull location in locations.conf or branch.conf.
   (Gordon Tyler, #534787)

=== modified file 'bzrlib/revisionspec.py'
--- bzrlib/revisionspec.py	2010-02-17 17:11:16 +0000
+++ bzrlib/revisionspec.py	2010-06-24 20:51:59 +0000
@@ -813,8 +813,14 @@
         revision_b = other_branch.last_revision()
         if revision_b in (None, revision.NULL_REVISION):
             raise errors.NoCommits(other_branch)
-        # pull in the remote revisions so we can diff
-        branch.fetch(other_branch, revision_b)
+        if branch is None:
+            branch = other_branch
+        else:
+            try:
+                # pull in the remote revisions so we can diff
+                branch.fetch(other_branch, revision_b)
+            except errors.ReadOnlyError:
+                branch = other_branch
         try:
             revno = branch.revision_id_to_revno(revision_b)
         except errors.NoSuchRevision:
@@ -840,6 +846,12 @@
             raise errors.NoCommits(other_branch)
         return other_branch.repository.revision_tree(last_revision)
 
+    def needs_branch(self):
+        return False
+
+    def get_branch(self):
+        return self.spec
+
 
 
 class RevisionSpec_submit(RevisionSpec_ancestor):

=== modified file 'bzrlib/tests/blackbox/test_log.py'
--- bzrlib/tests/blackbox/test_log.py	2010-06-08 08:24:39 +0000
+++ bzrlib/tests/blackbox/test_log.py	2010-06-25 08:01:24 +0000
@@ -158,6 +158,19 @@
         self.make_linear_branch()
         self.assertLogRevnos(['-c1'], ['1'])
 
+    def test_branch_revspec(self):
+        foo = self.make_branch_and_tree('foo')
+        bar = self.make_branch_and_tree('bar')
+        self.build_tree(['foo/foo.txt', 'bar/bar.txt'])
+        foo.add('foo.txt')
+        bar.add('bar.txt')
+        foo.commit(message='foo')
+        bar.commit(message='bar')
+        self.run_bzr('log -r branch:../bar', working_dir='foo')
+        self.assertEqual([bar.branch.get_rev_id(1)],
+                         [r.rev.revision_id
+                          for r in self.get_captured_revisions()])
+
 
 class TestLogExcludeCommonAncestry(TestLogWithLogCatcher):
 

